@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "boon" "20251212.1343"
-  "Ergonomic Command Mode for Emacs."
+(define-package "boon" "20260215.930"
+  "An Ergonomic Command Mode."
   '((emacs            "26.1")
     (dash             "2.12.0")
     (expand-region    "0.10.0")
     (multiple-cursors "1.3.0"))
   :url "https://github.com/jyp/boon"
-  :commit "28b3ff88673d73a4a907a47c22e82864a5c7a031"
-  :revdesc "28b3ff88673d")
+  :commit "1aa2b2f8f6c0b32cd600355bbeabc036624d0566"
+  :revdesc "1aa2b2f8f6c0")
